import { login, logout, getInfo, thirdPlatformLoginApi } from '@/api/login';
import { getToken, setToken, removeToken, setTenantid, removeThirdPlatform } from '@/utils/auth';

const user = {
  state: {
    token: getToken(),
    name: '',
    avatar: '',
    roles: [],
    permissions: [],
    userId: '',
    phonenumber: '',
    isThirdPlatformLogin: false
  },

  mutations: {
    SET_TOKEN: (state, token) => {
      state.token = token;
    },
    SET_NAME: (state, name) => {
      state.name = name;
    },
    SET_AVATAR: (state, avatar) => {
      state.avatar = avatar;
    },
    SET_ROLES: (state, roles) => {
      state.roles = roles;
    },
    SET_PERMISSIONS: (state, permissions) => {
      state.permissions = permissions;
    },
    SET_USERID: (state, userId) => {
      state.userId = userId;
    },
    SET_USERPHONE: (state, phonenumber) => {
      state.phonenumber = phonenumber;
    },
    SET_IS_THIRD_PLATFORM: (state, isThirdPlatformLogin) => {
      state.isThirdPlatformLogin = isThirdPlatformLogin ? true : false;
    }
  },

  actions: {
    // 登录
    Login({ commit }, userInfo) {
      const username = userInfo.username.trim();
      const password = userInfo.password;
      const code = userInfo.code;
      const uuid = userInfo.uuid;
      return new Promise((resolve, reject) => {
        login(username, password, code, uuid).then(res => {
          setToken(res.data.token);
          commit('SET_TOKEN', res.data.token);
          setTenantid(res.data.tenantId);
          resolve();
        }).catch(error => {
          reject(error);
        });
      });
    },

    // 获取用户信息
    GetInfo({ commit, state }) {
      return new Promise((resolve, reject) => {
        getInfo().then(res => {
          const user = res.data.user;
          const avatar = user.avatar ? user.avatar : '';
          if (res.data.roles && res.data.roles.length > 0) { // 验证返回的roles是否是一个非空数组
            commit('SET_ROLES', res.data.roles);
            commit('SET_PERMISSIONS', res.data.permissions);
          } else {
            commit('SET_ROLES', ['ROLE_DEFAULT']);
          }
          commit('SET_NAME', user.nickName);
          commit('SET_AVATAR', avatar);
          commit('SET_USERID', user.userId);
          commit('SET_USERPHONE', user.phonenumber);
          commit("SET_IS_THIRD_PLATFORM", res.data.isThirdPlatformLogin);
          resolve(res);
        }).catch(error => {
          reject(error);
        });
      });
    },

    // 退出系统
    LogOut({ commit, state }) {
      return new Promise((resolve, reject) => {
        logout(state.token).then(() => {
          commit('SET_TOKEN', '');
          commit('SET_ROLES', []);
          commit('SET_PERMISSIONS', []);
          removeToken();
          resolve();
        }).catch(error => {
          reject(error);
        });
      });
    },

    // 前端 登出
    FedLogOut({ commit }) {
      return new Promise(resolve => {
        commit('SET_TOKEN', '');
        commit('SET_USERID', "");
        commit('SET_ROLES', []);
        removeToken();
        resolve();
      });
    },


    // 免密登录 通过appkey登录
    async secretFreeLogin({ commit, state }, payload) {
      try {
        if (!payload) throw new Error("缺少platFormKey");
        const tokenInfo = await thirdPlatformLoginApi(payload);
        if (tokenInfo.code == 200) {
          setToken(tokenInfo.data.token);
          commit('SET_TOKEN', tokenInfo.data.token);
          setTenantid(tokenInfo.data.tenantId);
          return true;
        } else {
          throw new Error("appkey登录失败");
        }
      } catch (error) {
        throw error;
      }
    }

  }
};

export default user;
